/*
 * Copyright (c) 2001 Mark Fullmer and The Ohio State University
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *      $Id: hash_ip.h,v 1.4 2001/02/20 04:19:18 maf Exp $
 */

#if HAVE_CONFIG_H
 #include <config.h>
#endif

#include <sys/types.h>
#include "bytes.h"

int hash_ip_init();
int hash_ip_dump();

#define HASH_IP_STAT 

struct hash_ip_addr {

  u_short seg;    /* segment pointer */
  u_short off;    /* offset */
#ifdef HASH_IP_STAT
  u_long  hits;
#endif /* HASH_IP_STAT */
};

struct hash_ip_rec {

  u_int32 addr;         /* ip address */
  u_int64 nflows;       /* # of flows */
  u_int64 noctets;      /* # of octets */
  u_int64 npackets;     /* # of packets */
  u_int64 etime;        /* elapsed time */

  struct hash_ip_addr next; /* next record */
};


struct hash_ip_table {

  struct hash_ip_addr head;    /* head pointer to free records */
  struct hash_ip_addr *table;  /* lookup table */
  char **data;                 /* hash data */
  u_short lastoff;             /* last offset before need new allocation */

};

  
/* add a record to the table, or update the current record */
int hash_ip_update();

/* free storage */
int hash_ip_free();

/* lookup next key */
int hash_ip_next();

/* display histogram if hash table */
int hash_ip_hist();

